package cmd

import (
	"fmt"

	flags "github.com/orus-io/go-flags"
)

// ConfigWrite is a command that generates a configuration file.
type ConfigWrite struct {
	Output string `short:"o" long:"output" default:"config.ini" no-ini:"t" description:"output file"`

	parser *flags.Parser
}

// NewConfigWrite creates a ConfigWrite.
func NewConfigWrite(parser *flags.Parser) *ConfigWrite {
	return &ConfigWrite{parser: parser}
}

// Execute write out a configuration file.
func (c *ConfigWrite) Execute([]string) error {
	fp := flags.NewIniParser(c.parser)

	return fp.WriteFile(c.Output, flags.IniIncludeDefaults|flags.IniCommentDefaults|flags.IniDefault)
}

func parseFile(parser *flags.Parser) func(string) error {
	return func(filename string) error {
		iniParser := flags.NewIniParser(parser)

		log.Debug().Msg("Loading configuration file: " + filename)

		if err := iniParser.ParseFile(filename); err != nil {
			return &flags.Error{
				Type:    flags.ErrMarshal,
				Message: fmt.Sprintf("Error loading configuration file: %s", err),
			}
		}

		return nil
	}
}
